Learn R Programming

nlmrt (version 2013-9.24)

coef.nlmrt: Output model coefficients for nlmrt object.

Description

coef.nlmrt extracts and displays the coefficients for a model estimated by nlxb or nlfb in the nlmrt structured object.

Usage

## S3 method for class 'nlmrt':
coef(object, ...)

Arguments

object
An object of class 'nlmrt'
...
Any data needed for the function. We do not know of any!

Value

  • returns the coefficients from the nlmrt object.

Details

coef.nlmrt extracts and displays the coefficients for a model estimated by nlxb or nlfb.

See Also

Function nls(), packages optim and optimx.