Learn R Programming

nlmrt (version 2012-12.16)

print.nlmrt: Print method for an object of class nlmrt.

Description

Provide a summary output (but involving some serious computations!) of an object of class nlmrt from nlxb or nlfb from package nlmrt.

Usage

## S3 method for class 'nlmrt':
print(x, ...)

Arguments

x
An object of class 'nlmrt'
...
Any data needed for the function. We do not know of any!

Value

  • The numeric value of the sum of squares at the paramters.

Details

print.nlmrt performs a print method for an object of class 'nlmrt' that has been created by a routine such as nlfb or nlxb for nonlinear least squares problems.

See Also

Function nls(), packages optim and optimx.