nlxb(formula, start, trace=FALSE, data, lower=-Inf, upper=Inf, masked=NULL, control, ...)nls)
lhsvar ~ rhsexpression
for example,
y ~ b1/(1+b2*exp(-b3*tt))
You may also give this as a string.nlxb attempts to solve the nonlinear sum of squares problem by using
a variant of Marquardt's approach to stabilizing the Gauss-Newton method using
the Levenberg-Marquardt adjustment. This is explained in Nash (1979 or 1990) in
the sections that discuss Algorithm 23. (?? do we want a vignette. Yes, because
folk don't have access to book easily, but finding time.) In this code, we solve the (adjusted) Marquardt equations by use of the
qr.solve(). Rather than forming the J'J + lambda*D matrix, we augment
the J matrix with extra rows and the y vector with null elements.
others!!
nls(), packages optim and optimx.cat("See examples in nlmrt-package.Rd
")Run the code above in your browser using DataLab