Learn R Programming

nlmrt (version 2013-9.24)

nlxb: Nash variant of Marquardt nonlinear least squares solution via qr linear solver.

Description

Given a nonlinear model expressed as an expression of the form lhs ~ formula_for_rhs and a start vector where parameters used in the model formula are named, attempts to find the minimum of the residual sum of squares using the Nash variant (Nash, 1979) of the Marquardt algorithm, where the linear sub-problem is solved by a qr method.

Usage

nlxb(formula, start, trace=FALSE, data, lower=-Inf, upper=Inf, 
        masked=NULL, control, ...)

Arguments

formula
This is a modeling formula of the form (as in nls) lhsvar ~ rhsexpression for example, y ~ b1/(1+b2*exp(-b3*tt)) You may also give this as a string.
start
A named parameter vector. For our example, we could use start=c(b1=1, b2=2.345, b3=0.123)
trace
Logical TRUE if we want intermediate progress to be reported. Default is FALSE.
data
A data frame containing the data of the variables in the formula. This data may, however, be supplied directly in the parent frame.
lower
Lower bounds on the parameters. If a single number, this will be applied to all parameters. Default -Inf.
upper
Upper bounds on the parameters. If a single number, this will be applied to all parameters. Default Inf.
masked
Character vector of quoted parameter names. These parameters will NOT be altered by the algorithm.
control
A list of controls for the algorithm. These are: [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]
...
Any data needed for computation of the residual vector from the expression rhsexpression - lhsvar. Note that this is the negative of the usual residual, but the sum of squares is the same.

Value

  • A list of the following items
  • coefficientsA named vector giving the parameter values at the supposed solution.
  • ssquaresThe sum of squared residuals at this set of parameters.
  • residThe residual vector at the returned parameters.
  • jacobianThe jacobian matrix (partial derivatives of residuals w.r.t. the parameters) at the returned parameters.
  • fevalThe number of residual evaluations (sum of squares computations) used.
  • jevalThe number of Jacobian evaluations used.
  • rofftestDefault is TRUE. Use a termination test of the relative offset orthogonality type. Useful for nonlinear regression problems.
  • smallsstestDefault is TRUE. Exit the function if the sum of squares falls below (100 * .Machine$double.eps)^4 times the initial sumsquares. This is a test for a ``small'' sum of squares, but there are problems which are very extreme for which this control needs to be set FALSE.

Details

nlxb attempts to solve the nonlinear sum of squares problem by using a variant of Marquardt's approach to stabilizing the Gauss-Newton method using the Levenberg-Marquardt adjustment. This is explained in Nash (1979 or 1990) in the sections that discuss Algorithm 23. (?? do we want a vignette. Yes, because folk don't have access to book easily, but finding time.)

In this code, we solve the (adjusted) Marquardt equations by use of the qr.solve(). Rather than forming the J'J + lambda*D matrix, we augment the J matrix with extra rows and the y vector with null elements.

References

Nash, J. C. (1979, 1990) _Compact Numerical Methods for Computers. Linear Algebra and Function Minimisation._ Adam Hilger./Institute of Physics Publications

others!!

See Also

Function nls(), packages optim and optimx.

Examples

Run this code
cat("See examples in nlmrt-package.Rd
")

Run the code above in your browser using DataLab