nlxb or nlfb from package
nlmrt.## S3 method for class 'nlmrt':
print(x, ...)print.nlmrt performs a print method for an object of class 'nlmrt' that
has been created by a routine such as nlfb or nlxb for nonlinear
least squares problems.nls(), packages optim and optimx.